@@ -289,7 +289,9 @@ def agent():
     if write_file(home, home.lower(), whatap_home):
         os.environ['WHATAP_HOME'] = whatap_home
         
-        go()
+        t = threading.Thread(target=go)
+        t.setDaemon(True)
+        t.start()
         config(home)
         #startWhatapThread()
 
@@ -354,75 +356,40 @@ def go(batch=False):
     else:
         home = 'WHATAP_HOME_BATCH'
         file_name = AGENT_NAME + '.pid.batch'
-    
-    if go_kill(home, file_name, False):
-        try:
-            agent_cwd = os.environ.get(home)
-            if os.path.exists(os.path.join(agent_cwd, AGENT_NAME)):
-                os.remove(os.path.join(agent_cwd, AGENT_NAME))
 
-            source_cwd = os.path.join(os.path.join(os.path.dirname(__file__), 'agent'), platform.system().lower(),
-                                      ARCH[platform.machine()])
-            
-                
-            os.symlink(os.path.join(source_cwd, AGENT_NAME),
-                       os.path.join(agent_cwd, AGENT_NAME))
-            
-            os.environ['whatap.enabled'] = 'True'
-            process = subprocess.Popen('./{0}'.format(AGENT_NAME),
-                                       cwd=agent_cwd)
-            
-            # Write PID file
-            write_file(home, file_name, str(process.pid))
-        
-        except Exception as e:
-            print('WHATAP: AGENT ERROR: {}'.format(e))
-        else:
-            print('WHATAP: AGENT UP! (process name: {})\n'.format(AGENT_NAME))
+    def get_pname(id):
+        p = subprocess.Popen(["ps -o cmd= {}".format(id)], stdout=subprocess.PIPE, shell=True)
+        return str(p.communicate()[0])
+    pid = read_file(home, file_name)
+    if pid and 'whatap_python' in get_pname(pid):
+        return
+    try:
+        agent_cwd = os.environ.get(home)
+        if os.path.exists(os.path.join(agent_cwd, AGENT_NAME)):
+            os.remove(os.path.join(agent_cwd, AGENT_NAME))
+
+        source_cwd = os.path.join(os.path.join(os.path.dirname(__file__), 'agent'), platform.system().lower(),
+                                  ARCH[platform.machine()])
+
+
+        os.symlink(os.path.join(source_cwd, AGENT_NAME),
+                   os.path.join(agent_cwd, AGENT_NAME))
+
+        os.environ['whatap.enabled'] = 'True'
+        process = subprocess.Popen('./{0}'.format(AGENT_NAME),
+                                   cwd=agent_cwd)
+        # Write PID file
+        write_file(home, file_name, str(process.pid))
+        process.wait()
+
+    except Exception as e:
+        print('WHATAP: AGENT ERROR: {}'.format(e))
+    else:
+        print('WHATAP: AGENT UP! (process name: {})\n'.format(AGENT_NAME))
 
 
 import signal
 
-
-def go_kill(home, file_name, is_kill=True):
-    if is_kill == False:
-        return True
-
-    try:
-        pids = subprocess.check_output('pgrep {0}'.format(AGENT_NAME),
-                                       shell=True).split()
-    except Exception as e:
-        return True
-    else:
-        pid = read_file(home, file_name)
-        try:
-            if len(pid.split()):
-                os.kill(int(pid), signal.SIGKILL)
-            else:
-                if not read_file('WHATAP_HOME', AGENT_NAME + '.pid') \
-                        and not read_file('WHATAP_HOME_BATCH',
-                                          AGENT_NAME + '.pid.batch'):
-                    for pid in pids:
-                        os.kill(int(pid), signal.SIGKILL)
-                    
-                    write_file(home, AGENT_NAME + '.pid', '')
-                    write_file(home, AGENT_NAME + '.pid.batch', '')
-        
-        
-        except Exception as e:
-            logging.debug(e, extra={'id': ' AGENT UPGRADE ERROR'})
-            logging.debug(
-                'Try to execute command. \n  {}'.format(
-                    '`ps -ef | grep {}`'.format(AGENT_NAME)))
-            logging.debug(
-                'Next, `sudo kill -9 {}` or `sudo killall {}`'.format(
-                    pid, AGENT_NAME))
-            return False
-        else:
-            print('WHATAP: AGENT DOWN..')
-            return True
-
-
 from whatap.trace.mod.application_wsgi import interceptor, start_interceptor, \
     end_interceptor, trace_handler
 
