@@ -44,7 +44,7 @@ def trace_handler(fn, start=False):
             
             # check raise step error
             if ctx and ctx.error_step:
-                end_interceptor()
+                end_interceptor(ctx=ctx)
                 raise Exception(ctx.error_step)
             
             try:
@@ -83,27 +83,28 @@ def start_interceptor(ctx):
     
     return ctx
 
+def end_interceptor(thread_id=None, ctx= None):
+    if not ctx:
+        ctx = TraceContextManager.getContext(
+            thread_id) if thread_id else TraceContextManager.getLocalContext()
+    if not ctx:
+        return
 
-def end_interceptor(thread_id=None):
-    ctx = TraceContextManager.getContext(
-        thread_id) if thread_id else TraceContextManager.getLocalContext()
-    # print("end_interceptor txid:", ctx.id)
     if conf.dev:
         logging.debug('end   transaction id(seq): {}'.format(ctx.id),
                       extra={'id': 'WA112'})
         print('end   transaction id(seq): {}'.format(ctx.id),
                       dict(extra={'id': 'WA112'}))
-    
+
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
-    
+
     datas = [ctx.host, ctx.service_name, ctx.mtid, ctx.mdepth, ctx.mcaller_txid,
              ctx.mcaller_pcode, ctx.mcaller_spec, ctx.mcaller_url]
     ctx.elapsed = DateUtil.nowSystem() - start_time
 
     UdpSession.send_packet(PacketTypeEnum.TX_END, ctx, datas)
 
-
 def interceptor(rn_environ, *args, **kwargs):
     if not isinstance(rn_environ, tuple):
         rn_environ = (rn_environ, args[1])
@@ -173,7 +174,7 @@ def interceptor(rn_environ, *args, **kwargs):
             datas = ['HTTP-HEADERS', 'HTTP-HEADERS', text]
             ctx.start_time = DateUtil.nowSystem()
             UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-        end_interceptor()
+        end_interceptor(ctx=ctx)
     return callback
 
 
