@@ -1,5 +1,5 @@
 from whatap.trace.mod.application_wsgi import transfer, interceptor_httpc_request, \
-    trace_handler
+    trace_handler, interceptor_sock_connect
 
 
 def instrument_urllib3(module):
@@ -15,5 +15,7 @@ def instrument_urllib3(module):
             return callback
         
         return trace
-    
-    module.RequestMethods.request = wrapper(module.RequestMethods.request)
+    if hasattr(module, 'RequestMethods'):
+        module.RequestMethods.request = wrapper(module.RequestMethods.request)
+    if hasattr(module, 'HTTPConnection'):
+        module.HTTPConnection.connect = wrapper(interceptor_sock_connect)
\ No newline at end of file
