@@ -73,9 +73,8 @@ class TraceContextManager(object):
     
     @classmethod
     def getLocalContext(cls):
-        # print('TraceContextManager.getLocalContext:', cls.getCurrentKey())
-        return cls.getContext(cls.getCurrentKey())
-        
+        if not bool(cls.local.__dict__):
+            cls.local.context = None
         return cls.local.context
     
     @classmethod
@@ -99,7 +98,6 @@ class TraceContextManager(object):
     @classmethod
     def start(cls, o):
         key = cls.getCurrentKey()
-        print('TraceContextManager.start:', key)
         cls.local.context = o
         cls.entry.put(key, o)
 
