@@ -30,7 +30,7 @@ class Hexa32(object):
             return decode(str)
 
 
-CHARS = "0123456789abcdefghjkmnpqrstvwxyz"
+CHARS = "0123456789abcdefghijklmnopqrstuvwxyz"
 
 
 def encode(num):
@@ -54,7 +54,13 @@ def decode(string):
 
 
 if __name__=='__main__':
-    n=0
+
+    n=-7329592890664812990
+    s = 'z6bdvhspq4s0du'
+
+
     print(Hexa32.toString32(n))
-    s = 'x3vtsygczkpe47'
     print(Hexa32.toLong32(s))
+    
+    print(s==Hexa32.toString32(n))
+    print(n == Hexa32.toLong32(s))
